@@ -19,7 +19,7 @@ use base qw[ Tk::Derived Tk::Canvas ];
 Construct Tk::Widget 'RotatingGauge';
 
 
-our $VERSION   = '0.21';
+our $VERSION   = '0.22';
 
 
 #
@@ -35,6 +35,7 @@ sub Populate {
         -from      => [ 'PASSIVE', undef, undef, 0        ],
         -indicator => [ 'PASSIVE', undef, undef, 'red'    ],
         -labels    => [ 'PASSIVE', undef, undef, undef    ],
+        -orient    => [ 'PASSIVE', undef, undef, 'horiz'  ],
         -policy    => [ 'PASSIVE', undef, undef, 'rotate' ],
         -to        => [ 'PASSIVE', undef, undef, 100      ],
         -visible   => [ 'PASSIVE', undef, undef, 20       ],
@@ -71,9 +72,10 @@ sub value {
         if $value >= $to;
 
     # move the canvas items around.
-    my $v  = $self->{Configure}{-value};
-    my $dx = ($v - $value) * $self->{Configure}{-step};
-    $self->move( 'grid', $dx, 0 );
+    my $v = $self->{Configure}{-value};
+    my $d = ($v - $value) * $self->{Configure}{-step};
+    my @delta = $self->{Configure}{-is_horiz} ? ($d, 0) : (0, $d);
+    $self->move( 'grid', @delta );
     $self->{Configure}{-value} = $value;
 }
 
@@ -89,53 +91,68 @@ sub _draw_items {
     # get & compute some values...
     my $w = $self->{Configure}{-width};
     my $h = $self->{Configure}{-height};
+    my $is_horiz = ( 'vertical' !~ /$self->{Configure}{-orient}/ );
+    $self->{Configure}{-is_horiz} = $is_horiz;
 
     my $labels  = $self->{Configure}{-labels};
     my $from    = $self->{Configure}{-from};
     my $to      = $self->{Configure}{-to};
     my $visible = $self->{Configure}{-visible};
-    my $step    = $w / $visible;
+    my $step    = ($is_horiz ? $w : $h) / $visible;
 
     $self->{Configure}{-step}  = $step;
 
 
     # create the central line showing the value.
     if ( $self->{Configure}{-indicator} ne 'none' ) {
-        $self->createLine( $w/2, 0, $w/2, $h, -fill=>$self->{Configure}{-indicator}, -width=>2);
+        my @coords = $is_horiz ? ($w/2 , 0, $w/2 ,$h) : (0, $h/2, $w, $h/2);
+        $self->createLine( @coords, -fill=>$self->{Configure}{-indicator}, -width=>2);
     }
 
     # create the top / bottom lines if needed.
     if ( $self->{Configure}{-box} ne 'none' ) {
-        $self->createLine( 0, 1,  $w, 1,  -fill=>$self->{Configure}{-box} );
-        $self->createLine( 0, $h, $w, $h, -fill=>$self->{Configure}{-box} );
+        my @coords;
+        @coords = $is_horiz ? (1, 1, $w, 1) : (1, 1, 1, $h); 
+        $self->createLine( @coords, -fill=>$self->{Configure}{-box} );
+        @coords = $is_horiz ? (1, $h, $w, $h) : ($w, 1, $w, $h); 
+        $self->createLine( @coords, -fill=>$self->{Configure}{-box} );
     }
 
     # draw ticks $from .. $to.
     foreach my $i ( $from .. $to-1 ) {
+        my @coords;
         my $x    = $i * $step;
         my $text = defined $labels ?  $labels->[$i] : $i;
-        $self->createLine( $x, 0, $x, $h, -tags=>'grid' );
-        $self->createText( $x+$step/2, $h/2, -text=>$text, -tags=>'grid' );
+        @coords = $is_horiz ? ($x, 0, $x, $h) : (0, $x, $w, $x);
+        $self->createLine( @coords, -tags=>'grid' );
+        @coords = $is_horiz ? ($x+$step/2, $h/2) : ($w/2, $x+$step/2);
+        $self->createText( @coords, -text=>$text, -tags=>'grid' );
     }
     # draw $visible ticks before $from and after $to.
     foreach my $i ( 0 .. $visible ) {
+        my @coords;
         # before $from
         my $x    = -($i+1-$from) * $step;
         my $text = defined $labels ? $labels->[$to-1-$i] : $to-1-$i;
-        $self->createLine( $x, 0, $x, $h, -tags=>'grid' );
-        $self->createText( $x+$step/2, $h/2, -text=>$text, -tags=>'grid' );
+        @coords = $is_horiz ? ($x, 0, $x, $h) : (0, $x, $w, $x);
+        $self->createLine( @coords, -tags=>'grid' );
+        @coords = $is_horiz ? ($x+$step/2, $h/2) : ($w/2, $x+$step/2);
+        $self->createText( @coords, -text=>$text, -tags=>'grid' );
         # after $to
         $x    = ($to+$i) * $step;
         $text = defined $labels ? $labels->[$from+$i] : $from+$i;
-        $self->createLine( $x, 0, $x, $h, -tags=>'grid' );
-        $self->createText( $x+$step/2, $h/2, -text=>$text, -tags=>'grid' );
+        @coords = $is_horiz ? ($x, 0, $x, $h) : (0, $x, $w, $x);
+        $self->createLine( @coords, -tags=>'grid' );
+        @coords = $is_horiz ? ($x+$step/2, $h/2) : ($w/2, $x+$step/2);
+        $self->createText( @coords, -text=>$text, -tags=>'grid' );
     }
 
 
     # move the gauge to its initial value.
-    my $v  = $self->{Configure}{-value};
-    my $dx = ($visible/2-$v) * $step;
-    $self->move( 'grid', $dx, 0 );
+    my $v = $self->{Configure}{-value};
+    my $d = ($visible/2-$v) * $step;
+    my @delta = $is_horiz ? ($d,0) : (0,$d);
+    $self->move( 'grid', @delta );
 
 }
 
@@ -171,6 +188,10 @@ mileage counters...
 
 B<-background>
 
+B<-orient>
+
+See Tk::options for details of the standard options.
+
 
 
 =head1 WIDGET OPTIONS
